==> corehunt-2.7.1.tar.gz: corehunt-v2.7.1/main.cpp <==
/*
    *
    * This file is a part of CoreHunt.
    * A file search utility for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include "corehunt.h"

#include <QCommandLineParser>
#include <QFileInfo>
#include <QApplication>
#include <QIcon>


void startSetup()
{
    // set a icon across all the apps
    QIcon::setThemeName(QIcon::themeName());
}

int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    QApplication app(argc, argv);

    app.setQuitOnLastWindowClosed(true);

    startSetup();

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreHunt");

    QCommandLineParser parser;
    parser.addHelpOption();         // Help
    parser.addVersionOption();      // Version

	/* Optional: Path where the search begins */
    parser.addOption({ "path", "The path where the search begins.", "path" });

    /* Optional: Pattern we are searching for */
    parser.addOption({ "pattern", "Pattern which we are searching for.", "pattern" });

    /* No UI flag */
    parser.addOption({ "cli", "Use CLI only.", "" });

	/* Process the CLI args */
    parser.process(app);

    /* Initialize the app */
    corehunt hunt(parser.value("path"), parser.value("pattern"));

    if (parser.isSet("cli")) {
        if (not(parser.isSet("path") or parser.isSet("path"))) {
            CoreHuntIO::cout << "CoreHunt 2.7.0" << CoreHuntIO::endl;
			CoreHuntIO::cerr << "[ERROR:] Please specify path and pattern." << CoreHuntIO::endl;

			return 256;
		}

        hunt.setUseCli(true);
		hunt.search();

		return 0;
	}

	hunt.show();

    return app.exec();
}

==> corehunt-4.0.0.tar.gz: corehunt-v4.0.0/main.cpp <==
/*
    *
    * This file is a part of CoreHunt.
    * A file search utility for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
    *

    *
    * This program is free software; you can redistribute it and/or modify
    * it under the terms of the GNU General Public License as published by
    * the Free Software Foundation; either version 3 of the License, or
    * (at your option) any later version.
    *

    *
    * This program is distributed in the hope that it will be useful,
    * but WITHOUT ANY WARRANTY; without even the implied warranty of
    * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    * GNU General Public License for more details.
    *

    *
    * You should have received a copy of the GNU General Public License
    * along with this program; if not, vsit http://www.gnu.org/licenses/.
    *
*/

#include "corehunt.h"

#include <QCommandLineParser>
#include <QFileInfo>
#include <QApplication>
#include <QIcon>


void startSetup()
{
    // set a icon across all the apps
    QIcon::setThemeName(QIcon::themeName());
}

int main(int argc, char *argv[])
{
#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
    QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
#endif

    QApplication app(argc, argv);

    app.setQuitOnLastWindowClosed(true);

    startSetup();

    // Set application info
    app.setOrganizationName("CuboCore");
    app.setApplicationName("CoreHunt");

    QCommandLineParser parser;
    parser.addHelpOption();         // Help
    parser.addVersionOption();      // Version

	/* Optional: Path where the search begins */
    parser.addOption({ "path", "The path where the search begins.", "path" });

    /* Optional: Pattern we are searching for */
    parser.addOption({ "pattern", "Pattern which we are searching for.", "pattern" });

    /* No UI flag */
    parser.addOption({ "cli", "Use CLI only.", "" });

	/* Process the CLI args */
    parser.process(app);

    /* Initialize the app */
    corehunt hunt(parser.value("path"), parser.value("pattern"));

    if (parser.isSet("cli")) {
        if (not(parser.isSet("path") or parser.isSet("pattern"))) {
            CoreHuntIO::cout << "CoreHunt 2.9.0" << CoreHuntIO::endl;
			CoreHuntIO::cerr << "[ERROR:] Please specify path and pattern." << CoreHuntIO::endl;

			return 256;
		}

        hunt.setUseCli(true);
		hunt.search();

		return 0;
	}

	hunt.show();

    return app.exec();
}
